@@ -87,7 +87,7 @@ class Page:
     :   Instance of `input_type` to be used when invoking `spatula test`.
 
     `example_source`
-    :   Source to fetch when invokking `spatula test`.
+    :   Source to fetch when invoking `spatula test`.
 
     `dependencies`
     :   Dictionary mapping of names to `Page` objects that will be available before `process_page`.
@@ -406,6 +406,7 @@ class ListPage(Page):
         If [`SkipItem`](#SkipItem) is raised, `process_item` will continue to be called with
         the next item in the stream.
         """
+        warnings.warn(f"process_item not overridden on {self.__class__.__name__}")
         return item
 
 
